/**
 * @file
 * Center map by Node.
 */

(($, Drupal, drupalSettings) => {
  /**
   * Center map by Node.
   *
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Attaches common map style functionality to relevant elements.
   */
  Drupal.behaviors.geolocationCenterNode = {
    attach() {
      Drupal.geolocation.executeFeatureOnAllMaps(
        'leaflet_center_node',
        /**
         * @param {GeolocationLeafletMap} map - Current map.
         * @param {MarkerIconSettings} featureSettings - Settings for current feature.
         * @return {boolean} - False if no center set.
         */
        (map, featureSettings) => {
          const path = window.location.pathname;
          $.each(map.mapMarkers, (index, marker) => {
            if (marker.locationWrapper.data('nid') === path) {
              map.setCenterByCoordinates(marker.getLatLng());
              if (featureSettings.min_zoom !== '') {
                map.setZoom(featureSettings.min_zoom);
              }
            }
          });
          return false;
        },
        drupalSettings,
      );
    },
    detach() {},
  };
})(jQuery, Drupal, drupalSettings);
